/*!
 Redaxscript plugin for CLEditor
 Copyright 2013, Gary Aylward

 Dual licensed under the MIT or GPL Version 2 licenses.

 This plugin adds buttons to insert Redaxscript functions,
 "Read More" article breaks and code snippets
*/
/*jshint jquery:true */
(function ($)
{
	'use strict';
	// Handle the function button click event
	function rs_functionClick(e, data)
	{
		// Wire up the submit button click event
		$(data.popup).children(":button")
			.unbind("click")
			.bind("click", function (e)
			{
				// Get the editor
				var editor = data.editor;
				// Get the entered name
				var rs_function = $(data.popup).find(":text").val();
				if (rs_function !== "")
				{
					// Insert the function into the document
					var html = "<function>" + rs_function + "</function>";
					editor.execCommand(data.command, html, null, data.button);
				}
				// Hide the popup and set focus back to the editor
				editor.hidePopups();
				editor.focus();
			});
	}
	// Define the function button
	$.cleditor.buttons.rs_function =
	{
		name: "rs_function",
		image: "rs_function.gif",
		title: "Function",
		command: "inserthtml",
		popupName: "rs_function",
		popupClass: "cleditorPrompt",
		popupContent: "Enter function|arguments:<br><input type=text size=10><br><input type=button value=Submit>",
		buttonClick: rs_functionClick
	};
	// Add the button to the default controls after the source button
	$.cleditor.defaultOptions.controls = $.cleditor.defaultOptions.controls
		.replace("source", "source | rs_function");

	// Handle the break button click event
	function rs_breakClick(e, data)
	{
		// Insert HTML at the insertion point
		data.editor.execCommand(data.command, "<break></break><p></p>", null, data.button);
		data.editor.focus();
	}
	// Define the break button
	$.cleditor.buttons.rs_break =
	{
		name: "rs_break",
		image: "rs_break.gif",
		title: "Break",
		command: "inserthtml",
		popupName: "rs_break",
		popupClass: "cleditorPrompt",
		popupContent: "",
		buttonClick: rs_breakClick
	};
	// Add the button to the default controls after the function button
	$.cleditor.defaultOptions.controls = $.cleditor.defaultOptions.controls
		.replace("rs_function", "rs_function rs_break");

	// Handle the paste code button click event
	function rs_codeClick(e, data)
	{
		// Wire up the submit button click event handler
		$(data.popup).children(":button")
			.unbind("click")
			.bind("click", function (e)
		{
			// Insert the unformatted text replacing new lines with break tags
			var editor = data.editor;
			var $textarea = $(data.popup).find("textarea");
			var text = "<code>" + $textarea.val() + "</code>";
			if ($textarea.val() !== "")
			{
				editor.execCommand(data.command, text, null, data.button);
			}
			// Reset the text, hide the popup and set focus
			$textarea.val("");
			editor.hidePopups();
			editor.focus();

		});
	}
	// Define paste code button
	$.cleditor.buttons.rs_code =
	{
		name: "rs_code",
		image: "rs_code.gif",
		title: "Paste Code",
		command: "inserthtml",
		popupName: "rs_code",
		popupClass: "cleditorPrompt",
		popupContent: "Paste your code here:<br><textarea rows=4 cols=50></textarea><input type=button value=Submit>",
		buttonClick: rs_codeClick
	};
	// Add the button to the default controls after the break button
	$.cleditor.defaultOptions.controls = $.cleditor.defaultOptions.controls
		.replace("rs_break", "rs_break rs_code");

})(jQuery);